@@ -277,7 +277,7 @@ int read_int2_array( int f, short *iarray, int n )
    int i;
    signed char *buffer;
    int nread;
-   buffer = (signed char *) malloc( n * 2 );
+   buffer = (signed char *) FerMem_Malloc( n * 2, __FILE__, __LINE__ );
    if (!buffer)  return 0;
    nread = read( f, buffer, n*2 );
    if (nread<=0)  return 0;
@@ -286,7 +286,7 @@ int read_int2_array( int f, short *iarray, int n )
       /* don't forget about sign extension! */
       iarray[i] = (buffer[i*2] * 256) | buffer[i*2+1];
    }
-   free( buffer );
+   FerMem_Free( buffer, __FILE__, __LINE__ );
    return nread;
 #else
    int nread = read( f, iarray, n*2 );
@@ -314,7 +314,7 @@ int read_uint2_array( int f, unsigned short *iarray, int n )
    int i;
    unsigned char *buffer;
    int nread;
-   buffer = (unsigned char *) malloc( n * 2 );
+   buffer = (unsigned char *) FerMem_Malloc( n * 2, __FILE__, __LINE__ );
    if (!buffer)  return 0;
    nread = read( f, buffer, n*2 );
    if (nread<=0)  return 0;
@@ -322,7 +322,7 @@ int read_uint2_array( int f, unsigned short *iarray, int n )
    for (i=0;i<nread;i++) {
       iarray[i] = (buffer[i*2] << 8) | buffer[i*2+1];
    }
-   free( buffer );
+   FerMem_Free( buffer, __FILE__, __LINE__ );
    return nread;
 #else
    int nread = read( f, iarray, n*2 );
@@ -383,7 +383,7 @@ int read_int4_array( int f, int *iarray, int n )
    int j, nread;
    int *buffer;
 
-   buffer = (int *) malloc( (n+1)*4 );
+   buffer = (int *) FerMem_Malloc( (n+1)*4, __FILE__, __LINE__ );
    if (!buffer)
       return 0;
    nread = read( f, buffer, 4*n );
@@ -400,7 +400,7 @@ int read_int4_array( int f, int *iarray, int n )
          iarray[j] = buffer[j/2] & 0xffffffff;
       }
    }
-   free( buffer );
+   FerMem_Free( buffer, __FILE__, __LINE__ );
    return nread;
 #else
    int nread = read( f, iarray, 4*n );
@@ -470,13 +470,13 @@ int read_float4_array( int f, float *x, int n )
    long *buffer;
    int i, nread;
 
-   buffer = (long *) malloc( (n+1) * 4 );
+   buffer = (long *) FerMem_Malloc( (n+1) * 4, __FILE__, __LINE__ );
    if (!buffer) return 0;
    nread = read( f, buffer, n*4 );
    if (nread<=0)  return 0;
    nread /= 4;
    ieee_to_cray_array( x, buffer, nread );
-   free( buffer );
+   FerMem_Free( buffer, __FILE__, __LINE__ );
    return nread;
 #else
    int nread = read( f, x, 4*n );
@@ -601,14 +601,14 @@ int write_uint2_array( int f, const unsigned short *iarray, int n )
 #ifdef _CRAY
    int i, nwritten;
    unsigned char *buffer;
-   buffer = (unsigned char *) malloc( 2*n );
+   buffer = (unsigned char *) FerMem_Malloc( 2*n, __FILE__, __LINE__ );
    if (!buffer)  return 0;
    for (i=0;i<n;i++) {
       buffer[i*2] = (iarray[i] >> 8) & 0xff;
       buffer[i*2+1] = iarray[i] & 0xff;
    }
    nwritten = write( f, buffer, 2*n );
-   free( buffer );
+   FerMem_Free( buffer, __FILE__, __LINE__ );
    if (nwritten<=0)
       return 0;
    else
@@ -665,7 +665,7 @@ int write_int4_array( int f, const int *i, int n )
    int j, nwritten;
    char *buf, *b, *ptr;
 
-   b = buf = (char *) malloc( n*4 + 8 );
+   b = buf = (char *) FerMem_Malloc( n*4 + 8, __FILE__, __LINE__ );
    if (!b)
       return 0;
    ptr = (char *) i;
@@ -677,7 +677,7 @@ int write_int4_array( int f, const int *i, int n )
       *b++ = *ptr++;
    }
    nwritten = write( f, buf, 4*n );
-   free( buf );
+   FerMem_Free( buf, __FILE__, __LINE__ );
    if (nwritten<=0)
       return 0;
    else
@@ -742,12 +742,12 @@ int write_float4_array( int f, const float *x, int n )
    /* convert cray floats to IEEE and put into buffer */
    int nwritten;
    long *buffer;
-   buffer = (long *) malloc( n*4 + 8 );
+   buffer = (long *) FerMem_Malloc( n*4 + 8, __FILE__, __LINE__ );
    if (!buffer)
       return 0;
    cray_to_ieee_array( buffer, x, n );
    nwritten = write( f, buffer, 4*n );
-   free( buffer );
+   FerMem_Free( buffer, __FILE__, __LINE__ );
    if (nwritten<=0)
       return 0;
    else
