@@ -57,12 +57,7 @@
 
 #include <assert.h>
 #include <string.h>
-
-#ifdef NO_ENTRY_NAME_UNDERSCORES
-#define FORTRAN(a) a
-#else
-#define FORTRAN(a) a##_
-#endif
+#include "ferret.h"
 
 /* local static variable to contain the state */
 static int its_batch=0;
@@ -88,8 +83,8 @@ void FORTRAN(set_batch_graphics)(char *outfile, int *batmode)
   result = strstr(outfile,".gif"); 
   if (result)  {
       its_gif = -1;
-      if (length > 4)
-      {FORTRAN(save_frame_name)(outfile, &length);
+      if (length > 4) {
+          FORTRAN(save_frame_name)(outfile, &length);
       }
    }
   result = strstr(outfile,".ps"); 
