@@ -39,11 +39,9 @@
  */
 
 #include <string.h>
+#include "ferret.h"
 
-void c_strcmp_(in_ptr1, in_ptr2, out_ptr)
-     char** in_ptr1;
-     char** in_ptr2;
-     int* out_ptr;
+void FORTRAN(c_strcmp)(char **in_ptr1, char **in_ptr2, int *out_ptr)
 {
    char *str1;
    char *str2;
