@@ -43,23 +43,28 @@
 #include <ctype.h>
 #include <stdlib.h>
 #include <string.h>
+#include "ferret.h"
+#include "FerMem.h"
 
-void c_upcase_(in_ptr, out_ptr)
-     char** out_ptr;
-     char** in_ptr;
+void FORTRAN(c_upcase)(char **in_ptr, char **out_ptr)
 {
    char* tmp;
    char* tmp2;
 
-   if ( *out_ptr != NULL )
-      free(*out_ptr);
+   if ( (*out_ptr != NULL) && (*out_ptr != STRING_MISSING_VALUE) )
+      FerMem_Free(*out_ptr, __FILE__, __LINE__);
    if ( *in_ptr == NULL ) {
       /* undefined string given, so return an undefined string */
       *out_ptr = NULL;
       return;
    }
+   if ( *in_ptr == STRING_MISSING_VALUE ) {
+      /* missing string given, so return an missing string */
+      *out_ptr = STRING_MISSING_VALUE;
+      return;
+   }
 
-   *out_ptr = (char *) malloc(sizeof(char) * (strlen(*in_ptr) + 1));
+   *out_ptr = (char *) FerMem_Malloc(sizeof(char) * (strlen(*in_ptr) + 1), __FILE__, __LINE__);
    if ( *out_ptr == NULL )
       abort();
 
