@@ -39,19 +39,16 @@
  */
 
 #include <stdlib.h>
+#include "ferret.h"
+#include "FerMem.h"
 
-void save_c_string_(string, inlen, fer_ptr, offset, stat)
-     char* string;
-     int* inlen;
-     char*** fer_ptr;
-     int* offset;
-     int* stat;
+void FORTRAN(save_c_string)(char *string, int *inlen, char ***fer_ptr, int *offset, int *stat)
 {
    int i;
    char* ptr;
    char** each_str_ptr;
 
-   ptr = (char *) malloc(sizeof(char) * (*inlen + 1));
+   ptr = (char *) FerMem_Malloc(sizeof(char) * (*inlen + 1), __FILE__, __LINE__);
    if ( ptr != NULL ) {
       for (i=0; i<*inlen; i++)
          ptr[i] = string[i];
@@ -60,8 +57,8 @@ void save_c_string_(string, inlen, fer_ptr, offset, stat)
       /* save the pointer to the string */
       each_str_ptr = *fer_ptr;   /* holds pointer to the first string */
       each_str_ptr += *offset * 8/sizeof(char**); /* point to the desired string */ 
-      if ( *each_str_ptr != NULL )
-         free( *each_str_ptr );
+      if ( (*each_str_ptr != NULL) && (*each_str_ptr != STRING_MISSING_VALUE) )
+         FerMem_Free( *each_str_ptr, __FILE__, __LINE__ );
       *each_str_ptr = ptr;
 
       *stat = 0;
