@@ -60,10 +60,7 @@
 #include <stdio.h>
 
 
-void wHDF(file, image,r,g,b)
-     char *file;
-     XImage *image;
-     int r[],g[],b[];
+void wHDF(char *file, XImage *image, int r[], int g[], int b[])
 {
   fputs("**ERROR: wHDF not supported on this platform\n", stderr);
   exit(1);
