@@ -1,4 +1,4 @@
-#include <stdlib.h>
+#include "ferret.h"
 #include "EF_Util.h"
 
 void FORTRAN(ef_get_mr_list)(int mr_list[EF_MAX_ARGS])
