@@ -52,8 +52,8 @@
                     ticket 2448: for 2-digit years, put years prior to 50 into the 2000s
                     ticket 2449: report incorrect choice of date/ eurodate as an error
   V702 10/16 *acm*  ticket 2472: Allow yyyy/dd/mm in any of the date types.   
-  V702 11/16 *acm*   handling read errors in date/time reading
-
+  V702 11/16 *acm*  handling read errors in date/time reading
+  V702  1/17 *sh*   removal of block-oriented memory management
 */
 
 
@@ -79,9 +79,18 @@
 #include <string.h>
 #include <stdio.h>
 
-#include "ferretmacros.h"
+#include "fmtprotos.h"
 #include "ez_delimited_read.h"
+#include "ferret.h"
+#include "FerMem.h"
 
+static int decode_file(char* fname, char *recptr, char *delims, int *skip, int* maxrec, int* reclen, 
+                       int* nfields, int field_type[], int* nrec, DFTYPE** numeric_fields, 
+                       char*** text_fields, DFTYPE bad_flags[], int* status);
+static void decodeRec(char *recptr, char *delims, int* nfields, int field_type[], int rec, 
+                     DFTYPE** numeric_fields, char*** text_fields, DFTYPE bad_flags[], int* status);
+static void analRec(char *recptr, char *delims, int* nfields, int field_type[], int max_fields);
+static char *nexstrtok(char *s1, char *s2);
 
 /*
  *
@@ -98,27 +107,28 @@
  nfields - number of fields to decode on each record
  field_types - type of each field (input)
  mrlist - list of integers pointing to Ferret memory blocks
- memptr - pointer to base of Ferret "heap" storage
- mr_blk1 - memory chunk numbers indexed by mr_list
- mblk_size - chunk size within Ferret heap
+ mr_ptrs_val - integer containing the c pointer to array of mr memory pointers 
  mr_bad_flags - missing value flags indexed by mr_list
  *
  */
 
-
+void FORTRAN(decode_file_jacket)(char* fname, char *recptr, char *delims, int *skip, int* maxrec, int* reclen, 
+                                 int* nfields, int field_type[], int* nrec, int mrlist[], DFTYPE ***mr_ptrs_ptr, 
+                                 DFTYPE mr_bad_flags[], char ***mr_c_ptr, int* status)
+/* 1/17 --- pre-dynamic memory call
 void FORTRAN(decode_file_jacket)
 		( char* fname, char *recptr, char *delims, int *skip,
 		  int* maxrec, int* reclen, int* nfields,
 		  int field_type[], int* nrec,
 		  int mrlist[], DFTYPE *memptr, int mr_blk1[], int* mblk_size,
 		  DFTYPE mr_bad_flags[], char ***mr_c_ptr, int* status)
-
+*/
 {
+  DFTYPE** mr_ptrs = *mr_ptrs_ptr;
+  DFTYPE **numeric_fields  = (DFTYPE **) FerMem_Malloc(sizeof(DFTYPE*) * (*nfields), __FILE__, __LINE__);
+  DFTYPE *bad_flags        = (DFTYPE *)  FerMem_Malloc(sizeof(DFTYPE) * (*nfields), __FILE__, __LINE__);
 
-  DFTYPE **numeric_fields  = (DFTYPE **) malloc(sizeof(DFTYPE*) * (*nfields));
-  DFTYPE *bad_flags        = (DFTYPE *)  malloc(sizeof(DFTYPE) * (*nfields));
-
-  char ***text_fields     = (char ***) malloc(sizeof(char**) * (*nfields));
+  char ***text_fields     = (char ***) FerMem_Malloc(sizeof(char**) * (*nfields), __FILE__, __LINE__);
   int i, mr;
   int pinc = 8/sizeof(char*);  /* pointers spaced 8 bytes apart */
 
@@ -135,12 +145,12 @@ void FORTRAN(decode_file_jacket)
       if (field_type[i] == FTYP_CHARACTER )
 	{
 	  /* *kob* make sure were using size of real*4 float */
-	  text_fields[i] = (char**) (memptr + ((mr_blk1[mr]-1)*(*mblk_size)*4)/sizeof(float));
+	  text_fields[i] = (char**) mr_ptrs[i];
 	  mr_c_ptr[mr*pinc] = text_fields[i];
 	}
       else if (field_type[i] != FTYP_MISSING )
 	{
-	  numeric_fields[i] = memptr + (mr_blk1[mr]-1)*(*mblk_size);
+	  numeric_fields[i] = mr_ptrs[i];
 	  mr_c_ptr[mr*pinc] = (char**) NULL;
 	}
       /*
@@ -155,14 +165,13 @@ void FORTRAN(decode_file_jacket)
   /*
     at last we actually read the file
   */
-  decode_file (fname, recptr, delims, skip, 
-	       maxrec, reclen, nfields,
-	       field_type, nrec,
-	       numeric_fields, text_fields, bad_flags, status);
+  decode_file(fname, recptr, delims, skip, maxrec, reclen, 
+	      nfields, field_type, nrec, numeric_fields, 
+              text_fields, bad_flags, status);
 
-  free(numeric_fields);
-  free(text_fields);
-  free(bad_flags);
+  FerMem_Free(numeric_fields, __FILE__, __LINE__);
+  FerMem_Free(text_fields, __FILE__, __LINE__);
+  FerMem_Free(bad_flags, __FILE__, __LINE__);
 
   return;
 }
@@ -191,16 +200,15 @@ void FORTRAN(decode_file_jacket)
  */
 
 
-int decode_file (char* fname, char *recptr, char *delims, int *skip, 
-			  int* maxrec, int* reclen, int* nfields,
-			  int field_type[], int* nrec, DFTYPE** numeric_fields,
-			  char*** text_fields, DFTYPE bad_flags[], int* status)
-
+static int decode_file(char* fname, char *recptr, char *delims, int *skip, int* maxrec, int* reclen, 
+                       int* nfields, int field_type[], int* nrec, DFTYPE** numeric_fields, 
+                       char*** text_fields, DFTYPE bad_flags[], int* status)
 {
 
   FILE *fp;
   int slen, i;
   int pinc = 8/sizeof(char*);  /* pointers spaced 8 bytes apart */
+  char *startptr;
 
   *nrec = 0;
 
@@ -219,15 +227,16 @@ int decode_file (char* fname, char *recptr, char *delims, int *skip,
       if ( fgets(recptr,*reclen,fp) )
 	{
 	  /* skip leading blanks */
-	  while (*recptr==' ')
-	    recptr++;
+          startptr = recptr;
+	  while (*startptr ==' ')
+	    startptr++;
 
 	  /* overwrite the newline record terminator with a NULL */
-	  if ((slen = strlen(recptr)) > 0)
-	    if (recptr[slen-1] == '\n')
-	      recptr[slen-1] = '\0';
+	  if ((slen = strlen(startptr)) > 0)
+	    if (startptr[slen-1] == '\n')
+	      startptr[slen-1] = '\0';
 	  
-	  decodeRec(recptr, delims, nfields, field_type, *nrec,
+	  decodeRec(startptr, delims, nfields, field_type, *nrec,
 		    numeric_fields, text_fields, bad_flags, status);
 
 #ifdef diagnostic_output	  /* ************* */
@@ -277,6 +286,7 @@ int FORTRAN(anal_file) (char* fname, char *recptr, char *delims, int* skip,
   FILE *fp;
   int slen, i, rec;
   int nsuccess = 0;
+  char *startptr;
 
   fp = fopen(fname,"r");
 
@@ -300,14 +310,15 @@ int FORTRAN(anal_file) (char* fname, char *recptr, char *delims, int* skip,
 	  rec++;
 
 	  /* skip leading blanks */
-	  while (*recptr==' ')
-	    recptr++;
+          startptr = recptr;
+	  while (*startptr ==' ')
+	    startptr++;
 
 	  /* overwrite the newline record terminator with a NULL */
-	  if ((slen = strlen(recptr)) > 0)
-	    recptr[slen-1] = '\0';
+	  if ((slen = strlen(startptr)) > 0)
+	    startptr[slen-1] = '\0';
 	  
-	  analRec(recptr, delims, nfields, field_type, *max_fields);
+	  analRec(startptr, delims, nfields, field_type, *max_fields);
 
 	  /* check for unknown field types */
 	  i = 0;
@@ -360,10 +371,8 @@ int FORTRAN(anal_file) (char* fname, char *recptr, char *delims, int* skip,
  *
  */
 
-int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
-	      int rec,
-	      DFTYPE** numeric_fields, char*** text_fields, DFTYPE bad_flags[],
-	      int* status)
+static void decodeRec(char *recptr, char *delims, int* nfields, int field_type[], int rec, 
+                     DFTYPE** numeric_fields, char*** text_fields, DFTYPE bad_flags[], int* status)
 {
 
   char *p, *pnext, str1[2], errstr[2];
@@ -396,7 +405,7 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
     } else if (p==NULL || *p == '\0') {
       /* missing data field */
       if ( field_type[i] == FTYP_CHARACTER ) {
-	(*(text_fields+i))[rec*pinc] = (char *) malloc(sizeof(char)*2);
+	(*(text_fields+i))[rec*pinc] = (char *) FerMem_Malloc(sizeof(char)*2, __FILE__, __LINE__);
 	strcpy( (*(text_fields+i))[rec*pinc], blankstr );
       }
       else {
@@ -454,7 +463,7 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
 	  /* check for yyyy/mm/dd */
 	  if (idummy1 > 1800) {
 		  (*(numeric_fields+i))[rec] =
-		  days_from_day0_(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
+		  FORTRAN(days_from_day0)(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
 		  (*(numeric_fields+i))[rec] = rdum;
 		  if (*status != 3) (*(numeric_fields+i))[rec] = bad_flags[i];
 		  break;
@@ -469,14 +478,14 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
 	  }
 
 	  (*(numeric_fields+i))[rec] =
-	    days_from_day0_(&days_1900,&idummy3,&idummy1,&idummy2,&rdum,status);
+	    FORTRAN(days_from_day0)(&days_1900,&idummy3,&idummy1,&idummy2,&rdum,status);
 	  (*(numeric_fields+i))[rec] = rdum;
 	  if (*status != 3) (*(numeric_fields+i))[rec] = bad_flags[i];
 	/* force dates with dashes "-" to be in yyyy-mm-dd format *kob* */
 	} else if (sscanf(p,"%4d-%2d-%2d%1s",
 			  &idummy1,&idummy2,&idummy3,errstr) == 3) {
 	  (*(numeric_fields+i))[rec] =
-	    days_from_day0_(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
+	    FORTRAN(days_from_day0)(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
 	  (*(numeric_fields+i))[rec] = rdum; 
 	  if (*status != 3) (*(numeric_fields+i))[rec] = bad_flags[i];
 	  }
@@ -486,7 +495,7 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
 	      && idummy2>=1 && idummy2<=12
 	      && idummy3>=1 && idummy3<=31 ) {
 	  (*(numeric_fields+i))[rec] =
-	    days_from_day0_(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
+	    FORTRAN(days_from_day0)(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
 	  (*(numeric_fields+i))[rec] = rdum; }
 	else
 	  (*(numeric_fields+i))[rec] = bad_flags[i];
@@ -516,7 +525,7 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
 	  /* check for yyyy/mm/dd */
 	  if (idummy1 > 1800) {
 		  (*(numeric_fields+i))[rec] =
-		  days_from_day0_(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
+		  FORTRAN(days_from_day0)(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
 		  if (*status != 3) (*(numeric_fields+i))[rec] = bad_flags[i];
 	  } else {
 
@@ -529,7 +538,7 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
 		  }
 		  
 		  (*(numeric_fields+i))[rec] =
-		  days_from_day0_(&days_1900,&idummy3,&idummy1,&idummy2,&rdum,status);
+		  FORTRAN(days_from_day0)(&days_1900,&idummy3,&idummy1,&idummy2,&rdum,status);
 		  if (*status != 3) (*(numeric_fields+i))[rec] = bad_flags[i];
 	  }
 
@@ -546,26 +555,20 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
 		if (ndum == 5) tpart = idummy4 + idummy5/60.;
 
 	  (*(numeric_fields+i))[rec] =
-	    days_from_day0_(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
+	    FORTRAN(days_from_day0)(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
 	  (*(numeric_fields+i))[rec] = rdum + tpart/24.; 
 	  if (tpart == -999) (*(numeric_fields+i))[rec] = bad_flags[i];
 	  if (*status != 3) (*(numeric_fields+i))[rec] = bad_flags[i];
 	  }
 
 	/* check for yyyymmdd date */
-	else if ( (sscanf(p,"%4d%2d%2d%1s",&idummy1,&idummy2,&idummy3,&idummy4,&idummy5,&dummy,str1) >= 4)
+	else if ( (sscanf(p,"%4d%2d%2d%1s",&idummy1,&idummy2,&idummy3,str1) == 3)
 	      && idummy1>0
 	      && idummy3>=1 && idummy3<=12
 	      && idummy2>=1 && idummy2<=31 ) {
-		ndum = sscanf(p,"%4d%2d%2d%1s",&idummy1,&idummy2,&idummy3,&idummy4,&idummy5,&dummy,str1);
-		tpart = -999;	
-		if (ndum == 6) tpart = idummy4 + idummy5/60. + dummy/3600.;
-		if (ndum == 5) tpart = idummy4 + idummy5/60.;	
-
 		(*(numeric_fields+i))[rec] =
-		days_from_day0_(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
-		(*(numeric_fields+i))[rec] = rdum + tpart/24.; 	
-	    if (tpart == -999) (*(numeric_fields+i))[rec] = bad_flags[i];
+		FORTRAN(days_from_day0)(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
+		(*(numeric_fields+i))[rec] = rdum;
 		if (*status != 3) (*(numeric_fields+i))[rec] = bad_flags[i];
 	  }
 	else
@@ -587,7 +590,7 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
 	  /* check for yyyy/mm/dd */
 	  if (idummy1 > 1800) {
 		  (*(numeric_fields+i))[rec] =
-		  days_from_day0_(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
+		  FORTRAN(days_from_day0)(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
 		  (*(numeric_fields+i))[rec] = rdum;
 		  if (*status != 3) (*(numeric_fields+i))[rec] = bad_flags[i];
 		  break;
@@ -602,14 +605,14 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
 	  }
 
 	  (*(numeric_fields+i))[rec] =
-	    days_from_day0_(&days_1900,&idummy3,&idummy2,&idummy1,&rdum,status);
+	    FORTRAN(days_from_day0)(&days_1900,&idummy3,&idummy2,&idummy1,&rdum,status);
 	  (*(numeric_fields+i))[rec] = rdum;
 	  if (*status != 3) (*(numeric_fields+i))[rec] = bad_flags[i];
 	  /* force dates with dashes "-" to be in yyyy-mm-dd format *kob* */
 	} else if (sscanf(p,"%4d-%2d-%2d%1s",
 			  &idummy1,&idummy2,&idummy3,errstr) == 3) {
 	  (*(numeric_fields+i))[rec] =
-	    days_from_day0_(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
+	    FORTRAN(days_from_day0)(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
 	  (*(numeric_fields+i))[rec] = rdum;
 	  if (*status != 3) (*(numeric_fields+i))[rec] = bad_flags[i]; }
 	/* add check for yyyyddmm euro date *kob* */
@@ -618,7 +621,7 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
 	      && idummy3>=1 && idummy3<=12
 	      && idummy2>=1 && idummy2<=31 ) {
 	  (*(numeric_fields+i))[rec] =
-	    days_from_day0_(&days_1900,&idummy1,&idummy3,&idummy2,&rdum,status);
+	    FORTRAN(days_from_day0)(&days_1900,&idummy1,&idummy3,&idummy2,&rdum,status);
 	  (*(numeric_fields+i))[rec] = rdum;
 	  if (*status != 3) (*(numeric_fields+i))[rec] = bad_flags[i]; }
 	else
@@ -649,7 +652,7 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
 	  /* check for yyyy/mm/dd */
 	  if (idummy1 > 1800) {
 		  (*(numeric_fields+i))[rec] =
-		  days_from_day0_(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
+		  FORTRAN(days_from_day0)(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
 
 	  } else {
 
@@ -662,7 +665,7 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
 		  }
 		  
 		  (*(numeric_fields+i))[rec] =
-		  days_from_day0_(&days_1900,&idummy3,&idummy2,&idummy1,&rdum,status);
+		  FORTRAN(days_from_day0)(&days_1900,&idummy3,&idummy2,&idummy1,&rdum,status);
 	  }
 
 	  (*(numeric_fields+i))[rec] = rdum + tpart/24.;
@@ -679,26 +682,20 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
 		if (ndum == 5) tpart = idummy4 + idummy5/60.;
 
 	  (*(numeric_fields+i))[rec] =
-	    days_from_day0_(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
+	    FORTRAN(days_from_day0)(&days_1900,&idummy1,&idummy2,&idummy3,&rdum,status);
 	  (*(numeric_fields+i))[rec] = rdum + tpart/24.; 
 	  if (*status != 3) (*(numeric_fields+i))[rec] = bad_flags[i];
 	  if (tpart == -999) (*(numeric_fields+i))[rec] = bad_flags[i];
 	  }
 
 	/* add check for yyyyddmm euro date *kob* */
-	else if ( (sscanf(p,"%4d%2d%2d%1s",&idummy1,&idummy2,&idummy3,&idummy4,&idummy5,&dummy,str1) >= 4)
+	else if ( (sscanf(p,"%4d%2d%2d%1s",&idummy1,&idummy2,&idummy3,str1) == 3)
 	      && idummy1>0
 	      && idummy3>=1 && idummy3<=12
 	      && idummy2>=1 && idummy2<=31 ) {
-		ndum = sscanf(p,"%4d%2d%2d%1s",&idummy1,&idummy2,&idummy3,&idummy4,&idummy5,&dummy,str1);
-		tpart = -999;	
-		if (ndum == 6) tpart = idummy4 + idummy5/60. + dummy/3600.;
-		if (ndum == 5) tpart = idummy4 + idummy5/60.;	
-
 		(*(numeric_fields+i))[rec] =
-		days_from_day0_(&days_1900,&idummy1,&idummy3,&idummy2,&rdum,status);
-		(*(numeric_fields+i))[rec] = rdum + tpart/24.;
-	    if (tpart == -999) (*(numeric_fields+i))[rec] = bad_flags[i];
+		FORTRAN(days_from_day0)(&days_1900,&idummy1,&idummy3,&idummy2,&rdum,status);
+		(*(numeric_fields+i))[rec] = rdum;
 	    if (*status != 3) (*(numeric_fields+i))[rec] = bad_flags[i];  }
 	else
 	  (*(numeric_fields+i))[rec] = bad_flags[i];
@@ -739,7 +736,7 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
 	    p++;
 	  }
 	  (*(text_fields+i))[rec*pinc] =
-	    (char *) malloc(sizeof(char)*(strlen(p)+1));
+	    (char *) FerMem_Malloc(sizeof(char)*(strlen(p)+1), __FILE__, __LINE__);
 	  strcpy( (*(text_fields+i))[rec*pinc], p );
 	}
 	break;
@@ -775,14 +772,13 @@ int decodeRec(char *recptr, char *delims, int* nfields, int field_type[],
  *
  */
 
-void analRec(char *recptr, char *delims, int* nfields, int field_type[],
-	    int max_fields)
+static void analRec(char *recptr, char *delims, int* nfields, int field_type[], int max_fields)
 {
 
   char *p, *pnext, pstart[256], str1[2], latlon1[2];
   double dummy;
 
-  int idummy1, idummy2, idummy3, i, nfields_in;
+  int idummy1, idummy2, idummy3, nfields_in;
 
   p = recptr;
   nfields_in = *nfields;
@@ -919,8 +915,7 @@ void analRec(char *recptr, char *delims, int* nfields, int field_type[],
  *
  */
 
-char *nexstrtok(char *s1, char *s2)
-
+static char *nexstrtok(char *s1, char *s2)
      /*
        like strtok but sensitive to multiple (non-white space) delimiters
        as significant. For example, 2 commas together indicate a missing field.
@@ -969,11 +964,13 @@ char *nexstrtok(char *s1, char *s2)
 void FORTRAN(save_delimited_info) (int *nfields, int field_type[],
 				   char *delim, DelimFileInfo **ptr)
 {
-  DelimFileInfo *fi = (DelimFileInfo *) calloc(1, sizeof(DelimFileInfo));
-  int* _field_type  = (int *) malloc(sizeof(int) * (*nfields));
-  char* _delim      = (char *) malloc(sizeof(char) * (int)strlen(delim));
+  DelimFileInfo *fi = (DelimFileInfo *) FerMem_Malloc(sizeof(DelimFileInfo), __FILE__, __LINE__);
+  int* _field_type  = (int *) FerMem_Malloc(sizeof(int) * (*nfields), __FILE__, __LINE__);
+  char* _delim      = (char *) FerMem_Malloc(sizeof(char) * (int)strlen(delim) + 1, __FILE__, __LINE__);
   int i;
 
+  memset(fi, 0, sizeof(DelimFileInfo));
+
   for (i=0; i<*nfields; i++)
     _field_type[i] = field_type[i];
 
@@ -991,7 +988,7 @@ void FORTRAN(get_delimited_info) (int *nfields, int field_type[],
 				   char *delim, DelimFileInfo **ptr)
 {
 
-  int i,iout;
+  int i;
   DelimFileInfo *fi = *ptr;
 
   *nfields = fi->nfields;
@@ -1004,9 +1001,15 @@ void FORTRAN(get_delimited_info) (int *nfields, int field_type[],
 void FORTRAN(delete_delimited_info) (DelimFileInfo **ptr)
 {
   DelimFileInfo *fi = *ptr;
-  free(fi->fieldType);
-  free(fi->delim);
-  free(fi);
+  if ( fi != NULL ) {
+    if ( fi->fieldType != NULL )
+      FerMem_Free(fi->fieldType, __FILE__, __LINE__);
+    if ( fi->delim != NULL )
+      FerMem_Free(fi->delim, __FILE__, __LINE__);
+    memset(fi, 0, sizeof(DelimFileInfo));
+    FerMem_Free(fi, __FILE__, __LINE__);
+    *ptr = NULL;
+  }
   return;
 }
 
