@@ -39,23 +39,29 @@
     4/06 *kob*  change type of argument to double, for 64-bit build
  */
 
-#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
+#include "fmtprotos.h"
 #include "string_array.h"
+#include "FerMem.h"
 
-void string_array_clear_(double * string_array_header)
+void FORTRAN(string_array_clear)(void **string_array_header)
 {
-    int i;
-    SA_Head * head; 
+    SA_Head *head; 
+    int j;
 
-    if(*(SA_Head**)string_array_header){
-       head = *((SA_Head**)string_array_header);
-       for(i=0;i<head->array_size;i++) {
-	 free(head->ptr_array[i]);
+    if ( *string_array_header != NULL ) {
+       head = *string_array_header;
+       for (j = 0; j < head->array_size; j++) {
+	  FerMem_Free(head->ptr_array[j], __FILE__, __LINE__);
+	  head->ptr_array[j] = NULL;
        }
-       free(head->ptr_array);
-       free(head->hash_table);
-       free(head);
+       FerMem_Free(head->ptr_array, __FILE__, __LINE__);
+       FerMem_Free(head->strlen_array, __FILE__, __LINE__);
+       FerMem_Free(head->hash_table, __FILE__, __LINE__);
+       memset(head, 0, sizeof(SA_Head));
+       FerMem_Free(head, __FILE__, __LINE__);
+       *string_array_header = NULL;
     }
-    *string_array_header = 0;
 }
 
