@@ -48,38 +48,24 @@
 /* *kob* 10/03 v553 - gcc v3.x needs wchar.h included */
 
 #include <wchar.h>
-#include "udposix.h"
-#include "gks_implem.h"
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <time.h> 
+#include "udposix.h"
+#include "gks_implem.h"
+#include "pplmem.h"
 
-#ifdef NO_ENTRY_NAME_UNDERSCORES
-wait_on_resize (ws_id)
-#else
-wait_on_resize_ (ws_id)
-#endif
-
-Gint *ws_id;
-
+void FORTRAN(wait_on_resize)(int *ws_id)
 {
   WS_STATE_ENTRY *ws;
-
-  Display       **dpy;
-  Window         *win;
-  GC             *gc;
-
   XEvent          evnt;
-
-  int             xw_event,scr; 
+  int             xw_event; 
   time_t          t0,t_now,*tp;
 
 /*****************************************************************************/
 
   ws  = OPEN_WSID (*ws_id);
-  scr = DefaultScreen (ws->dpy);
-
   tp = &t_now;
   t0 = time(0);
   do { 
