@@ -28,71 +28,71 @@
 #ifndef XGKS_GIF_H
 #define XGKS_GIF_H
 
-extern int GIFrecSize	PROTO((
+extern int GIFrecSize(
     Gint            type
-));
-extern int GIFnextItem	PROTO((
+);
+extern int GIFnextItem(
     Metafile	*mf		/* Metafile structure */
-));
-extern int GIFwriteItem	PROTO((
+);
+extern int GIFwriteItem(
     Metafile      **mf,		/* Metafile structures */
     int             num,	/* Number of Metafiles */
     Gint	    type,	/* item type */
     Gint	    length,	/* item length */
     Gchar          *data	/* item data-record */
-));
-extern int GIFreadItem	PROTO((
+);
+extern int GIFreadItem(
     Metafile	*mf,		/* Metafile structure  */
     char        *record	/* input data-record */
-));
-extern int GIFmiOpen	PROTO((
+);
+extern int GIFmiOpen(
     Metafile	*mf		/* Metafile structure */
-));
-extern int GIFmoOpen	PROTO((
+);
+extern int GIFmoOpen(
     WS_STATE_PTR ws
-));
-extern int GIFmoClose	PROTO((
+);
+extern int GIFmoClose(
     Metafile	*mf
-));
-extern int GIFclear	PROTO((
+);
+extern int GIFclear(
     Metafile	*mf,
     int		num,
     Gclrflag	flag
-));
-extern int GIFredrawAllSeg	PROTO((
+);
+extern int GIFredrawAllSeg(
     Metafile	**mf,
     int		num
-));
-extern int GIFupdate	PROTO((
+);
+extern int GIFupdate(
     Metafile	**mf,
     int		num,
     Gregen	regenflag
-));
-extern int GIFdefer	PROTO((
+);
+extern int GIFdefer(
     Metafile	**mf,
     int		num,
     Gdefmode	defer_mode,
     Girgmode	regen_mode
-));
-extern int GIFmessage	PROTO((
+);
+extern int GIFmessage(
     Metafile	**mf,
     int		num,
     Gchar	*string
-));
-extern int GIFoutputGraphic	PROTO((
+);
+extern int GIFoutputGraphic(
     Metafile	*mf,
     int		num,
     Gint	code,
     Gint	num_pt,
     Gpoint	*pos
-));
-extern int GIFtext	PROTO((
+);
+extern int GIFtext(
     Metafile	*mf,
     int		num,
     Gpoint	*at,
     Gchar	*string
-));
-extern int GIFcellArray	PROTO((
+);
+extern int GIFcellArray(
     Metafile	*mf,
     int		num,
     Gpoint	*ll,
@@ -101,62 +101,62 @@ extern int GIFcellArray	PROTO((
     Gint	row,
     Gint	*colour,
     Gipoint	*dim
-));
-extern int GIFsetGraphSize	PROTO((
+);
+extern int GIFsetGraphSize(
     Metafile	*mf,
     int		num,
     Gint	code,
     double	size
-));
-extern int GIFcloseSeg	PROTO((
+);
+extern int GIFcloseSeg(
     Metafile	*mf,
     int		num
-));
-extern int GIFsetGraphAttr	PROTO((
+);
+extern int GIFsetGraphAttr(
     Metafile	*mf,
     int		num,
     Gint	code,
     Gint	attr
-));
-extern int GIFsetTextFP	PROTO((
+);
+extern int GIFsetTextFP(
     Metafile	*mf,
     int		num,
     Gtxfp	*txfp
-));
-extern int GIFsetCharUp	PROTO((
+);
+extern int GIFsetCharUp(
     Metafile	*mf,
     int		num,
     Gpoint	*up,
     Gpoint	*base
-));
-extern int GIFsetTextPath	PROTO((
+);
+extern int GIFsetTextPath(
     Metafile	*mf,
     int		num,
     Gtxpath	path
-));
-extern int GIFsetTextAlign	PROTO((
+);
+extern int GIFsetTextAlign(
     Metafile	*mf,
     int		num,
     Gtxalign	*align
-));
-extern int GIFsetFillStyle	PROTO((
+);
+extern int GIFsetFillStyle(
     Metafile	*mf,
     int		num,
     Gflinter	style
-));
-extern int GIFsetPatSize	PROTO((
+);
+extern int GIFsetPatSize(
     Metafile	*mf,
     int		num
-));
-extern int GIFsetPatRefpt	PROTO((
+);
+extern int GIFsetPatRefpt(
     Metafile	*mf,
     int		num
-));
-extern int GIFsetAsf	PROTO((
+);
+extern int GIFsetAsf(
     Metafile	*mf,
     int		num
-));
-extern int GIFsetLineMarkRep	PROTO((
+);
+extern int GIFsetLineMarkRep(
     Metafile	*mf,
     int		num,
     Gint	code,
@@ -164,84 +164,84 @@ extern int GIFsetLineMarkRep	PROTO((
     Gint	type,
     double	size,
     Gint	colour
-));
-extern int GIFsetTextRep	PROTO((
+);
+extern int GIFsetTextRep(
     Metafile	*mf,
     int		num,
     Gint	idx,
     Gtxbundl	*rep
-));
-extern int GIFsetFillRep	PROTO((
+);
+extern int GIFsetFillRep(
     Metafile	*mf,
     int		num,
     Gint	idx,
     Gflbundl	*rep
-));
-extern int GIFsetPatRep	PROTO((
+);
+extern int GIFsetPatRep(
     Metafile	*mf,
     int		num,
     Gint	idx,
     Gptbundl	*rep
-));
-extern int GIFsetColRep	PROTO((
+);
+extern int GIFsetColRep(
     Metafile	*mf,
     int		num,
     Gint	idx,
     Gcobundl	*rep
-));
-extern int GIFsetClip	PROTO((
+);
+extern int GIFsetClip(
     Metafile	*mf,
     int		num,
     Glimit	*rect
-));
-extern int GIFsetLimit	PROTO((
+);
+extern int GIFsetLimit(
     Metafile	*mf,
     int		num,
     Gint	code,
     Glimit	*rect
-));
-extern int GIFrenameSeg	PROTO((
+);
+extern int GIFrenameSeg(
     Metafile	*mf,
     int		num,
     Gint	old,
     Gint	new
-));
-extern int GIFsetSegTran	PROTO((
+);
+extern int GIFsetSegTran(
     Metafile	*mf,
     int		num,
     Gint	name,
     Gfloat	matrix[2][3]
-));
-extern int GIFsetSegAttr	PROTO((
+);
+extern int GIFsetSegAttr(
     Metafile	*mf,
     int		num,
     Gint	name,
     Gint	code,
     Gint	attr
-));
-extern int GIFsetSegVis	PROTO((
+);
+extern int GIFsetSegVis(
     Metafile	*mf,
     int		num,
     Gint	name,
     Gsegvis	vis
-));
-extern int GIFsetSegHilight	PROTO((
+);
+extern int GIFsetSegHilight(
     Metafile	*mf,
     int		num,
     Gint	name,
     Gseghi	hilight
-));
-extern int GIFsetSegPri	PROTO((
+);
+extern int GIFsetSegPri(
     Metafile	*mf,
     int		num,
     Gint	name,
     double	pri
-));
-extern int GIFsetSegDetect	PROTO((
+);
+extern int GIFsetSegDetect(
     Metafile	*mf,
     int		num,
     Gint	name,
     Gsegdet	det
-));
+);
 
 #endif	/* XGKS_PS_H not defined */
