@@ -28,71 +28,71 @@
 #define XGKS_PS_H
 
 
-extern int PSrecSize	PROTO((
+extern int PSrecSize(
     Gint            type
-));
-extern int PSnextItem	PROTO((
+);
+extern int PSnextItem(
     Metafile	*mf		/* Metafile structure */
-));
-extern int PSwriteItem	PROTO((
+);
+extern int PSwriteItem(
     Metafile      **mf,		/* Metafile structures */
     int             num,	/* Number of Metafiles */
     Gint	    type,	/* item type */
     Gint	    length,	/* item length */
     Gchar          *data	/* item data-record */
-));
-extern int PSreadItem	PROTO((
+);
+extern int PSreadItem(
     Metafile	*mf,		/* Metafile structure  */
     char        *record	/* input data-record */
-));
-extern int PSmiOpen	PROTO((
+);
+extern int PSmiOpen(
     Metafile	*mf		/* Metafile structure */
-));
-extern int PSmoOpen	PROTO((
+);
+extern int PSmoOpen(
     WS_STATE_PTR ws
-));
-extern int PSmoClose	PROTO((
+);
+extern int PSmoClose(
     Metafile	*mf
-));
-extern int PSclear	PROTO((
+);
+extern int PSclear(
     Metafile	*mf,
     int		num,
     Gclrflag	flag
-));
-extern int PSredrawAllSeg	PROTO((
+);
+extern int PSredrawAllSeg(
     Metafile	**mf,
     int		num
-));
-extern int PSupdate	PROTO((
+);
+extern int PSupdate(
     Metafile	**mf,
     int		num,
     Gregen	regenflag
-));
-extern int PSdefer	PROTO((
+);
+extern int PSdefer(
     Metafile	**mf,
     int		num,
     Gdefmode	defer_mode,
     Girgmode	regen_mode
-));
-extern int PSmessage	PROTO((
+);
+extern int PSmessage(
     Metafile	**mf,
     int		num,
     Gchar	*string
-));
-extern int PSoutputGraphic	PROTO((
+);
+extern int PSoutputGraphic(
     Metafile	*mf,
     int		num,
     Gint	code,
     Gint	num_pt,
     Gpoint	*pos
-));
-extern int PStext	PROTO((
+);
+extern int PStext(
     Metafile	*mf,
     int		num,
     Gpoint	*at,
     Gchar	*string
-));
-extern int PScellArray	PROTO((
+);
+extern int PScellArray(
     Metafile	*mf,
     int		num,
     Gpoint	*ll,
@@ -101,62 +101,62 @@ extern int PScellArray	PROTO((
     Gint	row,
     Gint	*colour,
     Gipoint	*dim
-));
-extern int PSsetGraphSize	PROTO((
+);
+extern int PSsetGraphSize(
     Metafile	*mf,
     int		num,
     Gint	code,
     double	size
-));
-extern int PScloseSeg	PROTO((
+);
+extern int PScloseSeg(
     Metafile	*mf,
     int		num
-));
-extern int PSsetGraphAttr	PROTO((
+);
+extern int PSsetGraphAttr(
     Metafile	*mf,
     int		num,
     Gint	code,
     Gint	attr
-));
-extern int PSsetTextFP	PROTO((
+);
+extern int PSsetTextFP(
     Metafile	*mf,
     int		num,
     Gtxfp	*txfp
-));
-extern int PSsetCharUp	PROTO((
+);
+extern int PSsetCharUp(
     Metafile	*mf,
     int		num,
     Gpoint	*up,
     Gpoint	*base
-));
-extern int PSsetTextPath	PROTO((
+);
+extern int PSsetTextPath(
     Metafile	*mf,
     int		num,
     Gtxpath	path
-));
-extern int PSsetTextAlign	PROTO((
+);
+extern int PSsetTextAlign(
     Metafile	*mf,
     int		num,
     Gtxalign	*align
-));
-extern int PSsetFillStyle	PROTO((
+);
+extern int PSsetFillStyle(
     Metafile	*mf,
     int		num,
     Gflinter	style
-));
-extern int PSsetPatSize	PROTO((
+);
+extern int PSsetPatSize(
     Metafile	*mf,
     int		num
-));
-extern int PSsetPatRefpt	PROTO((
+);
+extern int PSsetPatRefpt(
     Metafile	*mf,
     int		num
-));
-extern int PSsetAsf	PROTO((
+);
+extern int PSsetAsf(
     Metafile	*mf,
     int		num
-));
-extern int PSsetLineMarkRep	PROTO((
+);
+extern int PSsetLineMarkRep(
     Metafile	*mf,
     int		num,
     Gint	code,
@@ -164,84 +164,84 @@ extern int PSsetLineMarkRep	PROTO((
     Gint	type,
     double	size,
     Gint	colour
-));
-extern int PSsetTextRep	PROTO((
+);
+extern int PSsetTextRep(
     Metafile	*mf,
     int		num,
     Gint	idx,
     Gtxbundl	*rep
-));
-extern int PSsetFillRep	PROTO((
+);
+extern int PSsetFillRep(
     Metafile	*mf,
     int		num,
     Gint	idx,
     Gflbundl	*rep
-));
-extern int PSsetPatRep	PROTO((
+);
+extern int PSsetPatRep(
     Metafile	*mf,
     int		num,
     Gint	idx,
     Gptbundl	*rep
-));
-extern int PSsetColRep	PROTO((
+);
+extern int PSsetColRep(
     Metafile	*mf,
     int		num,
     Gint	idx,
     Gcobundl	*rep
-));
-extern int PSsetClip	PROTO((
+);
+extern int PSsetClip(
     Metafile	*mf,
     int		num,
     Glimit	*rect
-));
-extern int PSsetLimit	PROTO((
+);
+extern int PSsetLimit(
     Metafile	*mf,
     int		num,
     Gint	code,
     Glimit	*rect
-));
-extern int PSrenameSeg	PROTO((
+);
+extern int PSrenameSeg(
     Metafile	*mf,
     int		num,
     Gint	old,
     Gint	new
-));
-extern int PSsetSegTran	PROTO((
+);
+extern int PSsetSegTran(
     Metafile	*mf,
     int		num,
     Gint	name,
     Gfloat	matrix[2][3]
-));
-extern int PSsetSegAttr	PROTO((
+);
+extern int PSsetSegAttr(
     Metafile	*mf,
     int		num,
     Gint	name,
     Gint	code,
     Gint	attr
-));
-extern int PSsetSegVis	PROTO((
+);
+extern int PSsetSegVis(
     Metafile	*mf,
     int		num,
     Gint	name,
     Gsegvis	vis
-));
-extern int PSsetSegHilight	PROTO((
+);
+extern int PSsetSegHilight(
     Metafile	*mf,
     int		num,
     Gint	name,
     Gseghi	hilight
-));
-extern int PSsetSegPri	PROTO((
+);
+extern int PSsetSegPri(
     Metafile	*mf,
     int		num,
     Gint	name,
     double	pri
-));
-extern int PSsetSegDetect	PROTO((
+);
+extern int PSsetSegDetect(
     Metafile	*mf,
     int		num,
     Gint	name,
     Gsegdet	det
-));
+);
 
 #endif	/* XGKS_PS_H not defined */
